@@ -34,8 +34,8 @@ class Activity():
             self.subject = 'Rebel'
             self.object = 'Regime'
 
-        self.check(self.subject, 'subject')
-        self.check(self.object, 'object')
+        # self.check(self.subject, 'subject')
+        # self.check(self.object, 'object')
 
         self.verb = ''
         if self.properties['Ground'].value != '':
@@ -51,7 +51,7 @@ class Activity():
         if self.properties['Tactical'].value != '':
             self.verb = self.properties['Tactical'].value
 
-        self.check(self.verb, 'verb')
+        # self.check(self.verb, 'verb')
 
         self.properties['Title'].value = (
             self.post.short_date + " SYR " + self.subject + ' ' +
