@@ -10,13 +10,12 @@ import yaml
 
 class Home():
     def __init__(self):
-        self.version = '0.1.20dev'
+        self.version = '0.1.19dev'
 
         print(
-            '\nWelcome to SIGACTor ' + self.version
-            # + ', currently available '
-            # 'for the Syria team and reading posts from the '
-            # "Syrian Observatory for Human Rights' Facebook Page."
+            '\nWelcome to SIGACTor ' + self.version + ', currently available '
+            'for the Syria team and reading posts from the '
+            "Syrian Observatory for Human Rights' Facebook Page."
         )
 
         self.properties = [
@@ -50,7 +49,7 @@ class Home():
 
         self.source = input('\nWhat source should be retrieved? ')
 
-        print('\nPreparing CSV...')
+        # print('\nPreparing CSV...')
         self.today = datetime.now()
         self.csv_title = self.today.strftime('%Y-%m-%d-%H%M') + '.csv'
         self.csv_directory = os.path.join(os.path.expanduser('~'), 'SIGACTS')
@@ -62,10 +61,10 @@ class Home():
         )
         self.locations = yaml.load(locations)
 
-        if not os.path.exists(self.csv_directory):
-            os.makedirs(self.csv_directory)
+        # if not os.path.exists(self.csv_directory):
+            # os.makedirs(self.csv_directory)
 
-        self.csvwrite(self.properties)
+        # self.csvwrite(self.properties)
 
         self.unchecked_values = [
             'Title',
@@ -124,11 +123,12 @@ class Home():
             if item_date >= self.start_date:
                 self.posts.append(Post(self, item, item_date))
 
-        print(
-            '\nSaved CSV as', self.csv_path,
-        )
+        # print(
+            # '\nSaved CSV as', self.csv_path,
+        # )
 
     def csvwrite(self, values):
-        with open(self.csv_path, 'a') as csvfile:
-            csvwriter = csv.writer(csvfile, dialect='excel')
-            csvwriter.writerow(values)
+        pass
+        # with open(self.csv_path, 'a') as csvfile:
+            # csvwriter = csv.writer(csvfile, dialect='excel')
+            # csvwriter.writerow(values)
