@@ -131,7 +131,7 @@ class Property():
             ):
                 self.value = 'Anti-Regime'
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
         if self.name == 'Ground':
             if self.activity.content.contains('clashes'):
@@ -142,7 +142,7 @@ class Property():
                     self.value = 'DF'
                     self.y += 'Contains "died," "killed," or "dead." '
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
         if self.name == 'Air':
             if self.activity.content.contains('air'):
@@ -154,7 +154,7 @@ class Property():
             if self.activity.content.contains('targeted a fighter-jet'):
                 self.value = 'Ground-to-Air'
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
             if self.value:
                 self.activity.properties['Orientation'].value = 'Pro-regime'
@@ -171,7 +171,7 @@ class Property():
             if self.activity.content.contains('suicide'):
                 self.value = 'SVEST'
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
             if self.value:
                 self.activity.properties['Orientation'].value = 'Anti-Regime'
@@ -180,7 +180,7 @@ class Property():
             if self.activity.content.contains('execut'):
                 self.value = 'Execution'
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
         if self.name == 'Tactical':
             if self.activity.content.contains('ambush'):
@@ -191,18 +191,19 @@ class Property():
                 if not self.activity.content.contains('air raid'):
                     self.value = 'Raid'
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
         if self.name == 'Pro-regime KIA':
-            self.value = self.number_check(self.value)
-
-            self.value = self.number_check(self.value)
+            pass
+            # self.value = self.number_check(self.value)
 
         if self.name == 'Anti-regime KIA':
-            self.value = self.number_check(self.value)
+            pass
+            # self.value = self.number_check(self.value)
 
         if self.name == 'Anti-regime WIA':
-            self.value = self.number_check(self.value)
+            pass
+            # self.value = self.number_check(self.value)
 
         if self.name == 'Total KIA':
             self.value = self.total(
@@ -210,7 +211,7 @@ class Property():
                 self.activity.properties['Anti-regime KIA'].value
             )
 
-            self.value = self.number_check(self.value)
+            # self.value = self.number_check(self.value)
 
         if self.name == 'Total WIA':
             self.value = self.total(
@@ -218,7 +219,7 @@ class Property():
                 self.activity.properties['Anti-regime WIA'].value
             )
 
-            self.value = self.number_check(self.value)
+            # self.value = self.number_check(self.value)
 
         if self.name == 'Outcome':
             if self.activity.properties['Blast'].value:
@@ -226,7 +227,7 @@ class Property():
             else:
                 self.value = ''
 
-            self.value = self.activity.check(self.value, self.name)
+            # self.value = self.activity.check(self.value, self.name)
 
         if self.name == 'Full Text':
             self.value = self.post.content.text
